---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Is something not working as expected?**
Please edit this line and tell us what's not working.

**Steps to reproduce.**
Please help us reproduce the bug, by sharing:
1. your Gramex configuration,
2. the Python, HTML or JavaScript code that connects to the
   configuration
3. the Gramex log output, or browser console errors (if any)
4. a screenshot of the problem,


**Expected behavior**
Please tell us what should have happened?

**Your environment:**
 - OS: [e.g. Linux, OSX, Windows]
 - Browser [Chrome, Firefox, Safari, IE, etc.]
 - Python version: []
 - Gramex version: []

**Additional context**
Add any other context about the problem here.
